#!/bin/bash
# Title: Private Shotwell Script
# Author: TheOuterLinux (https://theouterlinux.gitlab.io)
# License: MIT
# Purpose: So as to have a separate instance of Shotwell for password
#          protected photos using zuluCrypt.
# Requirements:
#     - GNU/Linux operating system
#     - xterm
#     - zuluCrypt-cli
#     - 'xfce4-notifyd' or 'dialog' to display error messages
#
#       Optional:
#           - gksu for entering sudo password rather than using xterm;
#             the advantage is not having to keep an xterm window open.
#
# Last updated: 2023/11/16

#####[ Variables you can edit ]#####

# Enter the exact and full location of the password protected container 
# that contains your private images within the 
# IMAGE_CONTAINER_LOCATION='' below.

IMAGE_CONTAINER_LOCATION="/path/to/encrypted/container/with/images"

# Enter the exact and full location of the password protected container 
# that Shotwell will use to keep a database and thumbnails within the
# DATABASE_CONTAINER_LOCATION='' below. This container does not have to
# be large; a size more than 200MB would be "over-kill" for most people.
# This container would only have the directories "data" and "thumbs"
# inside, to which the "data" directory contains the "photo.db"
# database file and the "thumbs" directory contains thumbnails Shotwell
# generates.

DATABASE_CONTAINER_LOCATION="/path/to/encrypted/container/with/data/and/thumbs"

#####[ DO NOT EDIT BELOW THIS LINE]#####
IMAGE_CONTAINER_NAME="$(basename $IMAGE_CONTAINER_LOCATION)"
DATABASE_CONTAINER_NAME="$(basename $DATABASE_CONTAINER_LOCATION)"

#####[ FUNCTIONS ]#####

#Check the locations above for the required password protected containers
function LOCATIONCHECK(){
    if [ -f "$IMAGE_CONTAINER_LOCATION" ] && [ -f "$DATABASE_CONTAINER_LOCATION" ]; then PASSWORDS; else WHOOPS;fi
}

#Ask for passwords; sudo is required to use zuluCrypt because of mounting
function PASSWORDS(){
    xterm -T 'Password for image container...' -e zuluCrypt-cli -o -d "$IMAGE_CONTAINER_LOCATION" -m "$IMAGE_CONTAINER_NAME"
    xterm -T 'Password for database container...' -e zuluCrypt-cli -o -d "$DATABASE_CONTAINER_LOCATION" -m "$DATABASE_CONTAINER_NAME"
    if [ -d "/run/media/private/$USER/${IMAGE_CONTAINER_NAME}" ] && [ -d "/run/media/private/$USER/${DATABASE_CONTAINER_NAME}" ]; then SHOTWELL; else WHOOPS; fi
}

#Run this function if something goes wrong
function WHOOPS(){
    if [ -f '/usr/bin/notify-send' ]
    then
        notify-send 'Something went wrong.'
        notify-send 'Incorrect password or container locations?'
        notify-send 'Private Shotwell will not start.'
    else
        xterm -T 'Private Shotwell: Whoops...' -e dialog --msgbox "Something went wrong.\nIncorrect password or container locations?\nPrivate Shotwell will not start." 0 0
    fi
    #Run CLOSE function after notifying user that something went wrong...
    CLOSE
}

#This function opens Shotwell but uses a different data file than the default,
#which contains image locations and tags and keeps everything separate.
function SHOTWELL(){
    if [ -f "/usr/local/bin/gksu" ]
    then
        gksu shotwell --datadir="/run/media/private/$USER/${DATABASE_CONTAINER_NAME}/"
    else
        xterm -T 'Sudo is needed so Shotwell can read/write to database' -e sudo shotwell --datadir="/run/media/private/$USER/${DATABASE_CONTAINER_NAME}/"
    fi
    #Run CLOSE function after closing Private Shotwell...
    CLOSE
}

#Close Private Shotwell stuff and unmount containers; sudo is required
#to mount and unmount containers using zuluCrypt.
function CLOSE(){
    zuluCrypt-cli -q -d "$IMAGE_CONTAINER_LOCATION" -m "$IMAGE_CONTAINER_NAME"
    zuluCrypt-cli -q -d "$DATABASE_CONTAINER_LOCATION" -m "$DATABASE_CONTAINER_NAME"
    sudo -k #Clear sudo timer
}

#Start the script using the LOCATIONCHECK function...
LOCATIONCHECK
