#!/bin/bash
#
# This version of the Private Shotwell script is for use with encrypted
# partitions that you already know how to mount and not for file
# containers created by things like TrueCrypt, VeraCrypt, or ZuluCrypt.
#
# The "PARTITION_LOCATION" is the location of the mounted partition that
# is encrypted. If you see "[username]" or "[LongStreamOfRandomEXT4...]"
# or something similar, those parts need to be replaced with what they
# are related to.
#
# The "IMAGE_ROOTFOLDER_LOCATION" is the location of the directory that
# contains the images with the assumption that you have been using the
# "Import in place" option when adding images to Shotwell. You can leave
# this as relative to the "PARTITION_LOCATION" or just get rid of that
# part and use the full path.
#
# The "DATA_ROOTFOLDER_LOCATION" is the location of the directory that
# contains the "data" and "thumbs" directories in which the "data"
# subdirectory contains "photos.db". You can leave this as relative to
# the "PARTITION_LOCATION" or just get rid of that part and use the full
# path.
#
# If you are having trouble getting the full file-paths for the above
# mentioned locations, some terminal emulators, such as 
# 'xfce4-terminal', have drag-and-drop capability and you could then
# get the paths that way.

PARTITION_LOCATION="/media/[username]/[LongStreamOfRandomEXT4Nonsense]"
IMAGE_ROOTFOLDER_LOCATION="$PARTITION_LOCATION/path/to/Shotwell/ImagesDirectory"
DATA_ROOTFOLDER_LOCATION="$PARTITION_LOCATION/path/to/Shotwell/DataDirectory"

#####[ DO NOT EDIT BELOW THIS LINE ]#####
if [ ! -d "$PARTITION_LOCATION" ]
then
    if [ -f '/usr/bin/notify-send' ]
    then
        notify-send 'Hard drive not mounted.'
        notify-send 'Private Shotwell will not start.'
    else
        xterm -T 'Private Shotwell: Whoops...' -e dialog --msgbox "Hard drive not mounted.\nPrivate Shotwell will not start." 0 0
    fi
else
    shotwell --datadir="$DATA_ROOTFOLDER_LOCATION"
fi
